import 'package:flutter/material.dart';

import 'package:flutter_uis/Utils.dart';
import 'package:flutter_uis/UI.dart';

import 'package:flutter_uis/Widgets/BackButton4Stack/BackButton4Stack.dart';
import 'package:flutter_uis/Widgets/Screen/Screen.dart';

import 'widgets/HABDetailScreenFlightHeader.dart';
import 'widgets/HABDetailScreenFlightView.dart';
import '../../configs/theme.dart' as theme;
import '../../data/flights.dart' as data;
import 'Dimensions.dart';

class HABDetailScreen extends StatefulWidget {
  HABDetailScreen(this.index, {Key key}) : super(key: key);
  final int index;

  _HABDetailScreenState createState() => _HABDetailScreenState();
}

class _HABDetailScreenState extends State<HABDetailScreen> {
  PageController pageController;
  ScrollController backgroundController;
  int activePage;
  bool rendered = false;

  @override
  void initState() {
    this.activePage = widget.index;
    this.backgroundController = ScrollController();
    this.pageController = PageController(
      initialPage: widget.index,
      keepPage: true,
    );

    this.pageController.addListener(() {
      this.syncParallaxBackground();
      setState(() {});
    });

    WidgetsBinding.instance.addPostFrameCallback((_) {
      this.syncParallaxBackground();
      setState(() {
        this.rendered = true;
      });
    });

    super.initState();
  }

  @override
  void dispose() {
    this.pageController.dispose();
    super.dispose();
  }

  void setActivePage(int index) {
    setState(() {
      this.activePage = index;
    });
  }

  void syncParallaxBackground() {
    int listSize = data.flights.length - 1;

    final offset = this.pageController.offset;
    final totalSize = UI.width * (listSize);
    this.backgroundController.jumpTo(
          Utils.rangeMap(
            offset,
            0.0,
            totalSize,
            0.0,
            this.backgroundController.position.maxScrollExtent,
          ),
        );
  }

  void onKeyHandler(RawKeyEvent event) {
    final key = event.logicalKey.debugName;
    final rightKeys = ['Key K', 'Arrow Right'];
    final leftKeys = ['Key I', 'Arrow Left'];

    if (event.runtimeType.toString() == 'RawKeyUpEvent') {
      if (rightKeys.contains(key) && activePage < data.flights.length - 1) {
        this.pageController.animateToPage(
              this.activePage + 1,
              duration: Duration(milliseconds: 280),
              curve: Curves.easeIn,
            );
      } else if (leftKeys.contains(key) && activePage > 0) {
        this.pageController.animateToPage(
              this.activePage - 1,
              duration: Duration(milliseconds: 280),
              curve: Curves.easeIn,
            );
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    final fontStyle = Theme.of(context).textTheme.bodyText1.copyWith(
          fontFamily: 'Montserrat',
        );
    final rootTheme = Theme.of(context).copyWith(
      primaryColor: theme.primary,
      accentColor: theme.primary,
    );

    return RawKeyboardListener(
      autofocus: true,
      focusNode: FocusNode(),
      onKey: this.onKeyHandler,
      child: Screen(
        Dimensions.init,
        theme: rootTheme,
        textStyle: fontStyle,
        scaffoldBackgroundColor: Colors.white,
        builder: (_) {
          return Stack(
            fit: StackFit.expand,
            children: [
              // Parallax Image Background
              Positioned.fill(
                bottom: null,
                child: Container(
                  height: Dimensions.backgroudImageHeight,
                  foregroundDecoration: BoxDecoration(
                    color: theme.background2.withOpacity(0.8),
                  ),
                  child: ListView.builder(
                    itemCount: Dimensions.noOfImages,
                    scrollDirection: Axis.horizontal,
                    controller: this.backgroundController,
                    itemBuilder: (_, i) => Image.asset(
                      "assets/ma-hab/mountains.jpg",
                      fit: BoxFit.fitHeight,
                    ),
                  ),
                ),
              ),
              // Header
              HABDetailScreenFlightHeader(
                activePage: this.activePage,
                pageViewOffset:
                    this.rendered ? this.pageController?.offset : 0.0,
              ),
              // Horizontal PageView Builder
              PageView.builder(
                pageSnapping: true,
                controller: this.pageController,
                itemCount: data.flights.length,
                scrollDirection: Axis.horizontal,
                onPageChanged: this.setActivePage,
                itemBuilder: (context, index) {
                  final flight = data.flights[index];
                  return HABDetailScreenFlightView(flight, fontStyle);
                },
              ),
              // Back Button 4 Stack
              BackButton4Stack(),
            ],
          );
        },
      ),
    );
  }
}
